part of commons;

extension ExtensionOnNumbers on num {
  double _getPercent(num percent) {
    num p = percent < 0 ? 0 : percent;
    p = percent > 100 ? 100 : percent;

    return p / 100;
  }

  double get w {
    return MediaQuery.of(ContextService.context).size.width * _getPercent(this);
  }

  double get h {
    return MediaQuery.of(ContextService.context).size.height *
        _getPercent(this);
  }
}

extension MapExtensions on Map {
  void clearNull() {
    removeWhere((key, value) => value == null);
  }
}

extension ScaffoldColor on ColorScheme {
  Color? scaffoldBackgroundColor(BuildContext context) =>
      Theme.of(context).scaffoldBackgroundColor;
}

extension DateTimeExtension on DateTime {
  String get toYMD => DateFormat.yMd().format(this);
  bool get isToday => toYMD == DateTime.now().toYMD;
  bool get isYesterDay =>
      toYMD == DateTime.now().subtract(const Duration(days: 1)).toYMD;
}

extension StringExtension on String {
  DateTime toDateTime() => DateTime.parse(this);
  String get image => 'assets/images/${this}';

  /// this extension method will apply on [String]
  /// it will return a CamelCase from a given text
  String toCamelCase() {
    final camelCase = StringBuffer();
    split('_').forEach((namePart) => camelCase.write(
        '${namePart.trim()[0].toUpperCase()}${namePart.trim().substring(1)}'
            .trim()));

    return camelCase.toString();
  }
}

extension EnumExtensions on Enum {
  String get value => toString().split('.').last;
}
