part of commons;

///return result in meter
double distanceBetween(
  double startLatitude,
  double startLongitude,
  double endLatitude,
  double endLongitude,
) {
  const earthRadius = 6378137.0;
  final dLat = _toRadians(endLatitude - startLatitude);
  final dLon = _toRadians(endLongitude - startLongitude);

  final a = pow(sin(dLat / 2), 2) +
      pow(sin(dLon / 2), 2) *
          cos(_toRadians(startLatitude)) *
          cos(_toRadians(endLatitude));
  final c = 2 * asin(sqrt(a));

  return earthRadius * c;
}

double _toRadians(double degree) {
  return degree * pi / 180;
}

/// converter to asset files BitmapDescriptor.fromAssetImage,
Future getMarkerIcon(Function converter, String imagePath) async {
  final icon = await converter(
    ImageConfiguration.empty,
    imagePath,
  );
  return icon;
}

/// if it return true it's mean this position inside area
/// it's take [currentPosition] from type LatLng, and [vertices] List<LatLng>
bool isInsideArea(dynamic currentPosition, List<dynamic> vertices) {
  int intersectCount = 0;
  for (int j = 0; j < vertices.length - 1; j++) {
    if (_rayCastIntersect(currentPosition, vertices[j], vertices[j + 1])) {
      intersectCount++;
    }
  }

  return intersectCount.isOdd; // odd = inside, even = outside;
}

bool _rayCastIntersect(dynamic tap, dynamic vertA, dynamic vertB) {
  double aY = vertA.latitude;
  double bY = vertB.latitude;
  double aX = vertA.longitude;
  double bX = vertB.longitude;
  double pY = tap.latitude;
  double pX = tap.longitude;

  if ((aY > pY && bY > pY) || (aY < pY && bY < pY) || (aX < pX && bX < pX)) {
    return false; // a and b can't both be above or below pt.y, and a or
    // b must be east of pt.x
  }

  double m = (aY - bY) / (aX - bX); // Rise over run
  double bee = (-aX) * m + aY; // y = mx + b
  double x = (pY - bee) / m; // algebra is neat!

  return x > pX;
}
